==> dovecot-0.9.tar.gz: dovecot-0.9/src/login/main.c <==
/*
    Copyright (C) 2002 Timo Sirainen

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "common.h"
#include "lib-signals.h"
#include "restrict-access.h"
#include "auth.h"
#include "master.h"
#include "client.h"

#include <syslog.h>

AuthModule *default_auth;

IOLoop ioloop;
static IO io_listen;

static void sig_quit(int signo)
{
	io_loop_stop(ioloop);
}

static void login_accept(void *user_data, int listen_fd, IO io)
{
	IPADDR addr;
	int fd;

	fd = net_accept(listen_fd, &addr, NULL);
	if (fd == -1)
		return;

	(void)client_create(fd, &addr);
}

static void login_init(void)
{
	lib_init_signals(sig_quit);

	/* open the syslog immediately so chroot() won't break logging */
	openlog(PACKAGE "-login", LOG_NDELAY, LOG_MAIL);

	i_set_fatal_handler(i_syslog_fatal_handler);
        i_set_error_handler(i_syslog_error_handler);
        i_set_warning_handler(i_syslog_warning_handler);

	restrict_access_by_env();

	default_auth = &auth_master;
	auth_register(&auth_master);

	master_init();
	clients_init();
	io_listen = io_add(IMAP_LISTEN_FD, IO_READ, login_accept, NULL);
}

static void login_deinit(void)
{
        if (lib_signal_kill != 0)
		i_warning("Killed with signal %d", lib_signal_kill);

	io_remove(io_listen);

	clients_deinit();
	master_deinit();

	auth_unregister(&auth_master);
}

int main(int argc, char *argv[])
{
	/* NOTE: we start rooted, so keep the code minimal until
	   restrict_access_by_env() is called */
	lib_init();
	ioloop = io_loop_create();

	login_init();
        io_loop_run(ioloop);
	login_deinit();

	io_loop_destroy(ioloop);
	lib_deinit();

        return 0;
}

==> dovecot-0.94.tar.gz: dovecot-0.94/src/login/main.c <==
/*
    Copyright (C) 2002 Timo Sirainen

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "common.h"
#include "lib-signals.h"
#include "restrict-access.h"
#include "auth-connection.h"
#include "master.h"
#include "client.h"

#include <syslog.h>

IOLoop ioloop;
static IO io_listen;

static void sig_quit(int signo)
{
	io_loop_stop(ioloop);
}

static void login_accept(void *user_data, int listen_fd, IO io)
{
	IPADDR addr;
	int fd;

	fd = net_accept(listen_fd, &addr, NULL);
	if (fd == -1)
		return;

	(void)client_create(fd, &addr);
}

static void main_init(void)
{
	lib_init_signals(sig_quit);

	/* open the syslog immediately so chroot() won't break logging */
	openlog("imap-login", LOG_NDELAY, LOG_MAIL);

	i_set_panic_handler(i_syslog_panic_handler);
	i_set_fatal_handler(i_syslog_fatal_handler);
        i_set_error_handler(i_syslog_error_handler);
        i_set_warning_handler(i_syslog_warning_handler);

	restrict_access_by_env();

	auth_connection_init();
	master_init();
	clients_init();
	io_listen = io_add(IMAP_LISTEN_FD, IO_READ, login_accept, NULL);
}

static void main_deinit(void)
{
        if (lib_signal_kill != 0)
		i_warning("Killed with signal %d", lib_signal_kill);

	io_remove(io_listen);

	clients_deinit();
	master_deinit();
	auth_connection_deinit();
}

int main(int argc, char *argv[])
{
	/* NOTE: we start rooted, so keep the code minimal until
	   restrict_access_by_env() is called */
	lib_init();
	ioloop = io_loop_create();

	main_init();
        io_loop_run(ioloop);
	main_deinit();

	io_loop_destroy(ioloop);
	lib_deinit();

        return 0;
}
